@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.59'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.60'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.59 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-09-23.
+This document describes version 0.60 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-09-26.
 
 =head1 SEE ALSO
 
@@ -378,12 +378,47 @@ Examples:
  demo_cli_opts( array1 => ["elem1", "elem2"], int1 => 10, str1 => "a value");
 
 
+Result:
+
+ [
+   200,
+   "OK",
+   {
+     array1 => ["elem1", "elem2"],
+     full   => 1,
+     full2  => 1,
+     hash1  => { default => 1 },
+     int1   => 10,
+     int2   => 10,
+     str1   => "a value",
+   },
+ ]
 Summary for an example.
 
 
  demo_cli_opts( array1 => [1, 2], int1 => 20, str1 => "x");
 
 
+Result:
+
+ [
+   400,
+   "Can't parse argv",
+   undef,
+   {
+     logs => [
+               {
+                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.22.0/lib/site_perl/5.22.0/Perinci/Access/Schemeless.pm",
+                 func    => "Perinci::Access::Schemeless::action_call",
+                 line    => 477,
+                 package => "Perinci::Access::Schemeless",
+                 time    => 1443258017,
+                 type    => "create",
+               },
+             ],
+     prev => [500, "GetOptions failed"],
+   },
+ ]
 A second example.
 
 
@@ -529,7 +564,7 @@ Function summary.
 
 Examples:
 
- demo_cli_opts_shorter( bool1 => 1, str1 => "a value");
+ demo_cli_opts_shorter( bool1 => 1, str1 => "a value"); # -> [200, "OK", { bool1 => 1, str1 => "a value" }]
 
 
 Summary for an example.
