@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny::Args;
 
-our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.59'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.60'; # VERSION
 
 our %SPEC;
 
@@ -30,6 +30,27 @@ sub has_dot_args {
     [200, "OK", $args{'a.number'} * $args{'another.number'}];
 }
 
+# this Rinci metadata is already normalized
+$SPEC{has_date_arg} = {
+    v => 1.1,
+    summary => "This function contains a date argument",
+    args => {
+        'date' => {
+            schema => ['date', {req=>1}, {}],
+            pos => 0,
+            req => 1,
+        },
+    },
+};
+sub has_date_arg {
+    my %args = @_;
+    my $date = $args{date};
+    [200, "OK", {
+        "ref(value)" => ref($date),
+        "value (stringified)" => "$date",
+    }];
+}
+
 1;
 # ABSTRACT: Tests related to function arguments
 
@@ -45,7 +66,7 @@ Perinci::Examples::Tiny::Args - Tests related to function arguments
 
 =head1 VERSION
 
-This document describes version 0.59 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2015-09-23.
+This document describes version 0.60 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2015-09-26.
 
 =head1 DESCRIPTION
 
@@ -56,6 +77,30 @@ Perinci::CmdLine frameworks.
 =head1 FUNCTIONS
 
 
+=head2 has_date_arg(%args) -> [status, msg, result, meta]
+
+This function contains a date argument.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<date>* => I<date>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 has_dot_args(%args) -> [status, msg, result, meta]
 
 This function contains arguments with dot in their names.
